@@ -39,10 +39,8 @@ def get_first_gpu_type():
 
     # Extract the first GPU from the output
     gpu_info = result.stdout.strip().split("\n")[0]
-    # Extract the GPU type (e.g., NVIDIA H20)
-    gpu_type = gpu_info.split(":")[1].strip().split(" ")[0]
-
-    return gpu_type
+    
+    return gpu_info
 
 
 def serve(
